#!/bin/bash
ecc=$(cat /var/data/public_keys | tail -1 | awk -F\" '{print $2}')
name=$(cat /etc/hostname)
sn=$(cat /proc/cpuinfo | grep Serial |  awk '{print $3}')
eth=$(ifconfig eth0 | grep ether |  awk '{print $2}')
wlan=$(ifconfig wlan0 | grep ether |  awk '{print $2}')

miner_firmware=$(docker ps | grep miner | awk '{print $2}' | awk -F: '{print $2}')
current_height=$(curl -k -s https://api.helium.io/v1/blocks/height --connect-timeout 2 | jq .data.height)
miner_height=$(docker exec miner miner info height | awk '{print $2}')

QUAY_URL='https://quay.io/api/v1/repository/team-helium/miner/tag/?limit=20&page=1&onlyActiveTags=true'
ARCH=arm
miner_quay=$(curl -s "$QUAY_URL" --write-out '\nHTTP_Response:%{http_code}')
miner_response=$(echo "$miner_quay" | grep "HTTP_Response" | cut -d":" -f2)
if [[ $miner_response -ne 200 ]];
        then
        echo "Get firmware from server failed"
fi
miner_latest=$(echo "$miner_quay" | grep -v HTTP_Response | jq -c --arg ARCH $ARCH '[ .tags[] | select( .name | contains($ARCH)and contains("GA")) ][0].name' | cut -d'"' -f2)

patchUrl="http://minerback.heltec.cn/download/patch/"
patch_index_url=$patchUrl"indoor_hotspot_patch_index"
heltec_ver=$(cat /root/.func/update/version.txt | awk -F. '{print $1}' | awk -F- '{print $2}')
heltec_ver_newest=$(curl -s  -H 'Cache-Control: no-cache'  $patch_index_url | tail -1 | awk '{print $1}' | awk -F. '{print $1}' | awk -F- '{print $2}')

heltec_ver=$(echo V${heltec_ver:1:1}.${heltec_ver:2:1}.${heltec_ver:3:1})
heltec_ver_newest=$(echo V${heltec_ver_newest:1:1}.${heltec_ver_newest:2:1}.${heltec_ver_newest:3:1})

disk_G=$(df -h | grep /root | awk '{print $3}')
disk_p=$(df -h | grep /root | awk '{print $5}')
mem=$(free -h | grep Mem | awk '{print $7}')

dash="/tmp/dashinfo"
echo -n "{" > $dash
echo -n "\"address\":\"$ecc\"," >> $dash
echo -n "\"name\":\"$name\"," >> $dash
echo -n "\"sn\":\"$sn\"," >> $dash
echo -n "\"mac_eth\":\"$eth\"," >> $dash
echo -n "\"mac_wlan\":\"$wlan\"," >> $dash
echo -n "\"miner firmware\":\"$miner_firmware\"," >> $dash
echo -n "\"latest miner firmware\":\"$miner_latest\"," >> $dash
echo -n "\"current block height\":\"$miner_height\"," >> $dash
echo -n "\"latest block height\":\"$current_height\"," >> $dash
echo -n "\"current firmware\":\"$heltec_ver\"," >> $dash
echo -n "\"latest firmware\":\"$heltec_ver_newest\"," >> $dash
echo -n "\"disk used\":\"$disk_G($disk_p)\"," >> $dash
echo -n "\"memory available\":\"$mem\"" >> $dash
echo -n "}" >> $dash

cat $dash
